//
// QTVR Object Helper.js
// (c) 2005 based on QTVR helper.js from Martin Wengenmayer
//
// This script is in the public domain. Feel free to modify it or use 
// it as a starting point for your own creations.
//
// Purpose: 
//      Macro script which renders the N views which are needed to create a QTVR object.
//      The N views are saved in a folder specified by the user when starting this script. Views can be saved as TIFF, JPG, etc ...
//      QTVR Object movie can be then created with Quicktime Player and QTVREdit Object
//
// Usage:
//      Full details are available in the Readme file provided with this script
//      1. Set up the object or scene you want to render. Create a new camera with appropriate parameters (the script will change its name)
//      2. Position the camera at the center of the object or scene. Evaluate the radius required to render the object.
//      3. If required, modify the variables below (eg radius) but only the "Variables that can be changed by the user"
//      4. If changes were made to the variables (or to this script), save the file in the C3D script folder (where it should be, anyway)
//      5. Call the "QTVR Object Helper.js" script. The script will ask for a location and a name to save the images
//      6. Cheetah3D now renders the N necessary images for a QTVR object and will save them in the given folder.
//	7. Use "Quicktime Player Pro" or "Framed" (freeware - http://www.likelysoft.com/framed/ ) and "QTVREdit Object" ( ftp://ftp.apple.com/developer/Quicktime/Tools/QTVR/QTVREdit_Object.sit.hqx ) to create your object
//      8. Of course, QTVR Authoring tool (Apple) or VR Works can be also used once you have the images ready.

// Parameters (not currently implemented)
//var stepsize = xxxxx("Horizontal spacing (degree)",30);     //User's input ? in degree => Spacing between columns => One image every stepsize
//var cyclesize = xxxxx("Vertical spacing (degree)",45);      //User's input ? in degree => Spacing between rows

//Variables that can be changed by the user
var stepsize=12;                                            //in degree => Horizontal spacing between columns => One image every stepsize
var cyclesize=10;                                           //in degree => Vertical spacing between rows
var cyclenb=(180/cyclesize)+1;                              //number of rows (use only 90 for a scene (renders above horizon) or 180 for an object (renders above and below horizon )
var radius=5;			                            //radius of sphere to render
var imagetype="jpg";                                        //views will be saved as "imagetype" images. Possible format : tiff, jpg, png

//Other variables (do not change these)
var steps=360/stepsize;                                     //number of images per row or number of columns
var total=steps*cyclenb;                                    //total number of images to render (N)
var imagenb=100;                                            //number for first image (leave this at 100 because of a sorting bug in Framed )

OS.messageBox("Number of columns to be rendered ",steps);   //Keep this in mind for later use
OS.messageBox("Number of rows to be rendered ",cyclenb);    //Keep this in mind for later use
OS.messageBox("Total number of images to be rendered ",total);
OS.messageBox("Radius of sphere is ",radius);
OS.messageBox("Images will be saved with a : ","."+imagetype+" extension");

function main(doc){
    var cam=doc.getActiveCamera();
    if(cam==null) return; 
    
    var oldPOS=cam.getParameter("position");
    var oldROT=cam.getParameter("rotation");
    var oldFOV=cam.getParameter("fieldOfView");

//get directory and filename to save under
    var path=OS.runSavePanel();
    if(path==null){
	return;
	}
        
    var file=new File(path);
    var lastpathcomp=file.lastPathComponent();
    var dir=file.directory()+"/";
    var comps= lastpathcomp.split(/\./);
    var filename=comps[0];

//Change camera name
    cam.setParameter("name","QTVR object Cam");

//Position & Rotate the camera
    
    //Loop for rows   
    for(var j=0;j<cyclenb;j++){
        
        //Loop for columns
        for(var i=0;i<steps;i++){ 

	//Compute the new camera's position
	var newPOS=new Vector(oldPOS.x+radius*(Math.cos((i*Math.PI/180)*stepsize))*(Math.sin((j*Math.PI/180)*cyclesize)), oldPOS.y+radius*(Math.cos((j*Math.PI/180)*cyclesize)), oldPOS.z+radius*(Math.sin((i*Math.PI/180)*stepsize))*(Math.sin((j*Math.PI/180)*cyclesize)));
	
        //Compute the new camera's rotation
       	var newROT=new Vector(90-(i*stepsize), (j*cyclesize)-90, 0);
       
	//set the new position and rotation
	cam.setParameter("position",newPOS);
	cam.setParameter("rotation",newROT);

        //Render image
        //doc.render(dir+filename+imagenb+"."+imagetype);

        //increase image number for next view/image to be saved
        imagenb=imagenb+1

	}
    }

//restore camera state
    cam.setParameter("rotation",oldROT);
    cam.setParameter("fieldOfView",oldFOV);
    cam.setParameter("position",oldPOS);
}



